==> haskell-hls-rename-plugin-2.0.0.0-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-rename-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-rename-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-rename-plugin-2.0.0.0-1LW9jz5JZMIFZ82QhnuL5u
key:                  hls-rename-plugin-2.0.0.0-1LW9jz5JZMIFZ82QhnuL5u
license:              Apache-2.0
maintainer:           madine.oliver@gmail.com
author:               Oliver Madine
synopsis:             Rename plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  cf782eb4ee9c778d3c0cb5000803074c
exposed:              True
exposed-modules:      Ide.Plugin.Rename
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-rename-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-rename-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-rename-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-rename-plugin
hs-libraries:         HShls-rename-plugin-2.0.0.0-1LW9jz5JZMIFZ82QhnuL5u
depends:
    base-4.17.2.1 containers-0.6.7 extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK
    ghc-9.4.8 ghc-exactprint-1.6.1-B4bBZ972uNZAtSHLc0cZx
    ghcide-2.0.0.0-L5q9I4ZYiMTCYArbowTz3S
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    hie-compat-0.3.0.0-CbBComUrkWGfIGRN5OUf4
    hiedb-0.4.3.0-Ly8C2l75ueqI5cGKIK4jpr
    hls-plugin-api-2.0.0.0-1mAvF1as5w95rctfx0vZ4l
    hls-refactor-plugin-2.0.0.0-HVsKJpu38GXG6ct3fKXBMr
    lsp-1.6.0.0-G6O3LkQ8zqqEpZl3VXzGEp
    lsp-types-1.6.0.1-LwmrTvIMAzugL58xEnCbi
    mod-0.2.0.1-7yhVTK6nAa4AmhaSrC0EEH
    syb-0.7.2.4-1AaSJ4gAQqF80sCpMGQHRf text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-rename-plugin/html/hls-rename-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-rename-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-rename-plugin-2.0.0.0-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-rename-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-rename-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-rename-plugin-2.0.0.0-GC9eXmvNX0d473AEJaMcVW
key:                  hls-rename-plugin-2.0.0.0-GC9eXmvNX0d473AEJaMcVW
license:              Apache-2.0
maintainer:           madine.oliver@gmail.com
author:               Oliver Madine
synopsis:             Rename plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  424ec8d2982e3b24fe75304c2885a5b7
exposed:              True
exposed-modules:      Ide.Plugin.Rename
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-rename-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-rename-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-rename-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-rename-plugin
hs-libraries:         HShls-rename-plugin-2.0.0.0-GC9eXmvNX0d473AEJaMcVW
depends:
    base-4.17.2.1 containers-0.6.7 extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK
    ghc-9.4.8 ghc-exactprint-1.6.1-1pC2UooR1UK8f5nfgopCxy
    ghcide-2.0.0.0-AWKPNAHSA153zaZtgTpP3V
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    hie-compat-0.3.0.0-CbBComUrkWGfIGRN5OUf4
    hiedb-0.4.3.0-GbWrJ2JFYWf3KewwEzZ3xf
    hls-plugin-api-2.0.0.0-8UXQK9xyJ6Qq1nXPMTcOV
    hls-refactor-plugin-2.0.0.0-AbIl1V1xNFfJ9BxZ4KD12J
    lsp-1.6.0.0-LOrWurGUfcm1ZXl1RcyPxv
    lsp-types-1.6.0.1-KcckgHP1cSAQeTZDkGSeD
    mod-0.2.0.1-AfHuOcNqjz072esMCQmeTm
    syb-0.7.2.4-1AaSJ4gAQqF80sCpMGQHRf text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-rename-plugin/html/hls-rename-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-rename-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
